version 9
capture log close
log using bgresults.log, t replace

***************************************************************************************
***Program to generate the data and results of                                      ***  
***Bernanke & Gurkaynak. 2001.                                                      *** 
***Is Growth Exogenous? Taking Mankiw, Romer and Weil Seriously                     *** 
***                                                                                 ***
***This program generates all results except for nonlinear system estimations.      ***  
***Stata 9 program and data file.                                                   ***
***                                                                                 ***
***I thank Patrick Toche for sending me the code to generate and save the graphs    ***
***in Stata 9 format that he wrote for classroom use.                               ***
***That is the only change from the original (Stata version 6) program.             ***
***                                                                                 ***
***For questions or comments please e-mail refet@bilkent.edu.tr                     ***
***************************************************************************************

cd c:\growth
use bg2001

set more off
graph set print logo off


************************
***GENERATE VARIABLES***
************************

*LABOR FORCE

gen lf60=pop60*padult60
gen lf65=pop65*padult65
gen lf80=pop80*padult80
gen lf85=pop85*padult85
gen lf95=pop95*padult95

replace lf60=pop61*padult61 if country=="TUNISIA"
replace lf95=pop94*padult94 if country=="TURKEY"
replace lf95=pop94*padult94 if country=="SINGAPORE"

label var lf60 "Labor force in 1960"

*Average SAVING RATES
egen sk6095t=rmean(ki60-ki95)
egen sk6595t=rmean(ki65-ki95)
egen sk6085t=rmean(ki60-ki85)
egen sk6580t=rmean(ki65-ki80)
egen sk8095t=rmean(ki80-ki95)

gen sk6095=sk6095t/100
gen sk6595=sk6595t/100
gen sk6085=sk6085t/100
gen sk6580=sk6580t/100
gen sk8095=sk8095t/100


label var sk6095 "Average saving rate 1960-95"

*Average LABOR FORCE GROWTH RATES

gen glf6095=(lf95/lf60)^(1/35)-1
replace glf6095=(lf95/lf60)^(1/34)-1 if country=="TUNISIA"
replace glf6095=(lf95/lf60)^(1/34)-1 if country=="TURKEY"
replace glf6095=(lf95/lf60)^(1/34)-1 if country=="SINGAPORE"
gen glf6595=(lf95/lf65)^(1/30)-1
replace glf6595=(lf95/lf65)^(1/29)-1 if country=="TURKEY"
replace glf6595=(lf95/lf65)^(1/29)-1 if country=="SINGAPORE"
gen glf6085=(lf85/lf60)^(1/25)-1
replace glf6085=(lf85/lf60)^(1/24)-1 if country=="TUNISIA"
gen glf6580=(lf80/lf65)^(1/15)-1
gen glf8095=(lf95/lf80)^(1/15)-1
replace glf8095=(lf95/lf80)^(1/14)-1 if country=="TURKEY"
replace glf8095=(lf95/lf80)^(1/14)-1 if country=="SINGAPORE"

label var glf6095 "Average growth rate of labor force 1960-95"

*Average investment in human capital

egen sh6095=rmean(lfsh60-lfsh95)
egen sh6595=rmean(lfsh65-lfsh95)
egen sh6085=rmean(lfsh60-lfsh85)
egen sh6580=rmean(lfsh65-lfsh80)
egen sh8095=rmean(lfsh80-lfsh95)

label var sh6095 "Average investment in human capital 1960-95"

*GDP per worker

gen yl60=rgdpch60/padult60
gen yl65=rgdpch65/padult65
gen yl80=rgdpch80/padult80
gen yl85=rgdpch85/padult85
gen yl95=rgdpch95/padult95

replace yl60=rgdpch61/padult61 if country=="TUNISIA"
replace yl95=rgdpch94/padult94 if country=="TURKEY"
replace yl95=rgdpch94/padult94 if country=="SINGAPORE"

label var yl60 "GDP per worker 1960"

*Average growth rate of per worker output

gen gavg6085=(ln(yl85)-ln(yl60))/25
replace gavg6085=(ln(yl85)-ln(yl60))/24 if country=="TUNISIA"

gen gavg6095=(ln(yl95)-ln(yl60))/35
replace gavg6095=(ln(yl95)-ln(yl60))/34 if country=="TUNISIA"
replace gavg6095=(ln(yl95)-ln(yl60))/34 if country=="TURKEY"
replace gavg6095=(ln(yl95)-ln(yl60))/34 if country=="SINGAPORE"


label var gavg6085 "Average growth rate of output per worker 1960-85"

*Regression variables

*Unrestricted

gen lnyl85=ln(yl85)
gen lnyl95=ln(yl95)
gen lnsk6085=ln(sk6085)
gen lnsk6095=ln(sk6095)
gen lngd6085=ln(glf6085+0.05)
gen lngd6095=ln(glf6095+0.05)
gen lnsh6085=ln(sh6085)
gen lnsh6095=ln(sh6095)
 

label var lnyl85 "Log of output per worker"
label var lnsk6085 "Log of avg. savings rate 1960-85"
label var lngd6085 "Log of (avg. labor force growth rate + g(=0.02) + depreciation(=0.03))"
label var lnsh6085 "Log of avg. investment in human capital, 1960-85"

*Restricted 

gen dskn6085=lnsk6085-lngd6085
gen dskn6095=lnsk6095-lngd6095  
gen dshn6085=lnsh6085-lngd6085
gen dshn6095=lnsh6095-lngd6095

label var dskn6085 "lnsk6085-lngd6085"
label var dshn6085 "lnsh6085-lngd6085"


***First to calculate CAPITAL STOCK*** 

*Generate total output

for num 50/98: gen totalyX = rgdpchX*popX 
label var totaly50 "Total output in 1950"

*Generate investment series

for num 50/98: gen investX=totalyX*kiX/100
label var invest50 "Investment in 1950"

*Generate avg growth rate of output to use in estimating initial capital stock
*Then calculate capital stock using perpetual inventory

gen gk50=(totaly60/totaly50)^(1/10)-1
gen gk55=(totaly65/totaly55)^(1/10)-1
gen gk60=(totaly70/totaly60)^(1/10)-1
*Data for Tunisia starts at 1961
replace gk60=(totaly71/totaly61)^(1/10)-1 if country=="TUNISIA"
label var gk50 "Average growth rate of output 1950-60"

*Estimate initial capital stock
*Assume capital and output grow at the same rate and DEPRECIATION RATE is 6%
*Then calculate capital stock using perpetual inventory

gen kstk49=invest50/(gk50+0.06)
for num 50/98 \ num 49/97: gen kstkX=kstkY*(1-0.06)+investX if kstk49~=.

replace kstk54=invest55/(gk55+0.06) if kstk49==.
for num 55/98 \ num 54/97: replace kstkX=kstkY*(1-0.06)+investX if kstk49==. & kstk54~=.

replace kstk59=invest60/(gk60+0.06) if kstk49==. & kstk54==.
replace kstk60=kstk59*(1-0.06)+invest60 if kstk49==. & kstk54==. & kstk59~=.
replace kstk60=invest61/(gk60+0.06) if country=="TUNISIA"
for num 61/98 \ num 60/97: replace kstkX=kstkY*(1-0.06)+investX if kstk49==. & kstk54==. & kstk60~=.

label var kstk49 "Total capital stock, 1949"

*Calculate nonresidential capital stock
for num 49/98: gen nrkstkX=kstkX*avgrnrk
for num 49/98: replace nrkstkX=kstkX*(2/3) if avgrnrk==.

label var nrkstk49 "Non-residential capital stock 1949"

**Generate GROWTH RATE OF CAPITAL***
*Start from 1965 to allow initial capital stock to depreciate*

gen gk6595=((nrkstk95/nrkstk65)^(1/30))-1
gen gk6580=((nrkstk80/nrkstk65)^(1/15))-1
gen gk8095=((nrkstk95/nrkstk80)^(1/15))-1

replace gk6595=((nrkstk94/nrkstk65)^(1/29))-1 if country=="TURKEY"
replace gk8095=((nrkstk94/nrkstk80)^(1/14))-1 if country=="TURKEY"
replace gk6595=((nrkstk94/nrkstk65)^(1/29))-1 if country=="SINGAPORE"
replace gk8095=((nrkstk94/nrkstk80)^(1/14))-1 if country=="SINGAPORE"


label var gk6595 "Average growth rate of non-residential capital, 1965-95"

***Generate STOCK of HUMAN CAPITAL, assuming 7% returns to education***

*Information on educational attainment from Barro & Lee (2000)
*Weights come from Collins & Bosworth(1996, BPEA)

gen hc7p60= lu1560*100+(lp1560-lpc1560)*125+lpc1560*150+(ls1560-lsc1560)*187+lsc1560*225 +(lh1560-lhc1560)*262+lhc1560*300
gen hc7p65= lu1565*100+(lp1565-lpc1565)*125+lpc1565*150+(ls1565-lsc1565)*187+lsc1565*225 +(lh1565-lhc1565)*262+lhc1565*300
gen hc7p70= lu1570*100+(lp1570-lpc1570)*125+lpc1570*150+(ls1570-lsc1570)*187+lsc1570*225 +(lh1570-lhc1570)*262+lhc1570*300
gen hc7p75= lu1575*100+(lp1575-lpc1575)*125+lpc1575*150+(ls1575-lsc1575)*187+lsc1575*225 +(lh1575-lhc1575)*262+lhc1575*300
gen hc7p80= lu1580*100+(lp1580-lpc1580)*125+lpc1580*150+(ls1580-lsc1580)*187+lsc1580*225 +(lh1580-lhc1580)*262+lhc1580*300
gen hc7p85= lu1585*100+(lp1585-lpc1585)*125+lpc1585*150+(ls1585-lsc1585)*187+lsc1585*225 +(lh1585-lhc1585)*262+lhc1585*300
gen hc7p90= lu1590*100+(lp1590-lpc1590)*125+lpc1590*150+(ls1590-lsc1590)*187+lsc1590*225 +(lh1590-lhc1590)*262+lhc1590*300
gen hc7p95= lu1595*100+(lp1595-lpc1595)*125+lpc1595*150+(ls1595-lsc1595)*187+lsc1595*225 +(lh1595-lhc1595)*262+lhc1595*300

label var hc7p60 "Stock of Human capital in 1960 assuming 7% return to education"

*Generate GROWTH RATE of HUMAN CAPITAL

gen gh76595=((hc7p95/hc7p65)^(1/30))-1
gen gh76580=((hc7p80/hc7p65)^(1/15))-1
gen gh78095=((hc7p95/hc7p80)^(1/15))-1

replace gh76595=((hc7p95/hc7p70)^(1/25))-1 if country=="BENIN" | country=="RWANDA"
replace gh76595=((hc7p95/hc7p75)^(1/20))-1 if country=="EGYPT"
replace gh76595=((hc7p95/hc7p85)^(1/10))-1 if country=="CONGO"

replace gh76580=((hc7p80/hc7p70)^(1/10))-1 if country=="BENIN" | country=="RWANDA"
replace gh76580=((hc7p80/hc7p75)^(1/5))-1 if country=="EGYPT"

replace gh78095=((hc7p95/hc7p85)^(1/10))-1 if country=="CONGO"

label var gh76595 "Average growth rate of human capital 1965-95, 7% return to education"

***Generate GROWTH RATE of TOTAL OUTPUT***

gen gy6595=((totaly95/totaly65)^(1/30))-1
gen gy6580=((totaly80/totaly65)^(1/15))-1
gen gy8095=((totaly95/totaly80)^(1/15))-1

replace gy6595=((totaly94/totaly65)^(1/29))-1 if country=="TURKEY"
replace gy8095=((totaly94/totaly80)^(1/14))-1 if country=="TURKEY"
replace gy6595=((totaly94/totaly65)^(1/29))-1 if country=="SINGAPORE"
replace gy8095=((totaly94/totaly80)^(1/14))-1 if country=="SINGAPORE"


label var gy6595 "Average growth rate of Real GDP, 1965-1995"

***Generate Labor's share to be used in growth accounting***

gen labshare=acosadj if acosadj~=. & gsample==1
replace labshare=imosadj if acosadj==. & imosadj~=. & gsample==1
replace labshare=lfadj if acosadj==. & imosadj==. & lfadj~=. & gsample==1

sum labshare

label var labshare "Labor's share --acosadj, if not imosadj, if not lfadj" 




*********************
***MRW REGRESSIONS***
*********************


*1960-1985

*Textbook Solow Model
*Unconstrained 1960-85

*Nonoil
reg lnyl85 lnsk6085 lngd6085 if nonoil==1
test lnsk6085+lngd6085=0
*Inter
reg lnyl85 lnsk6085 lngd6085 if inter==1 
test lnsk6085+lngd6085=0
*OECD
reg lnyl85 lnsk6085 lngd6085 if oecd==1
test lnsk6085+lngd6085=0

*Constrained 1960-85
*  --Standard error of alpha calculated by delta method--

*Nonoil
reg lnyl85 dskn6085 if nonoil==1
matrix cov=e(V)
disp "Alpha " (_b[dskn6085]/(1+_b[dskn6085]))
disp "Std err " (sqrt(cov[1,1])/((1+_b[dskn6085])^2))

*Inter
reg lnyl85 dskn6085 if inter==1
matrix cov=e(V)
disp "Alpha " (_b[dskn6085]/(1+_b[dskn6085]))
disp "Std. err " (sqrt(cov[1,1])/((1+_b[dskn6085])^2))


*OECD
reg lnyl85 dskn6085 if oecd==1
matrix cov=e(V)
disp "Alpha " (_b[dskn6085]/(1+_b[dskn6085]))
disp "Std. err " (sqrt(cov[1,1])/((1+_b[dskn6085])^2))


*Augmented Solow Model
*Unconstrained 1960-85

*Nonoil
reg lnyl85 lnsk6085 lngd6085 lnsh6085 if nonoil==1
test lnsk6085+lngd6085+lnsh6085=0

*Inter
reg lnyl85 lnsk6085 lngd6085 lnsh6085 if inter==1
test lnsk6085+lngd6085+lnsh6085=0

*OECD
reg lnyl85 lnsk6085 lngd6085 lnsh6085 if oecd==1
test lnsk6085+lngd6085+lnsh6085=0

*Constrained 1960-85

*Nonoil
reg lnyl85 dskn6085 dshn6085 if nonoil==1
matrix cov=e(V)
disp "Alpha " _b[dskn6085]/(1+_b[dskn6085]+_b[dshn6085])
disp "Std err. alpha " sqrt(((((1+_b[dshn6085])^2)*cov[1,1])+((_b[dskn6085]^2)*cov[2,2])-(2*_b[dskn6085]*(1+_b[dshn6085])*cov[2,1]))/((1+_b[dskn6085]+_b[dshn6085])^4))
disp "Beta " _b[dshn6085]/(1+_b[dskn6085]+_b[dshn6085])
disp "Std err. beta " sqrt(((((1+_b[dskn6085])^2)*cov[2,2])+((_b[dshn6085]^2)*cov[1,1])-(2*_b[dshn6085]*(1+_b[dskn6085])*cov[2,1]))/((1+_b[dskn6085]+_b[dshn6085])^4))

*Inter
reg lnyl85 dskn6085 dshn6085 if inter==1
matrix cov=e(V)
disp "Alpha " _b[dskn6085]/(1+_b[dskn6085]+_b[dshn6085])
disp "Std err. alpha " sqrt(((((1+_b[dshn6085])^2)*cov[1,1])+((_b[dskn6085]^2)*cov[2,2])-(2*_b[dskn6085]*(1+_b[dshn6085])*cov[2,1]))/((1+_b[dskn6085]+_b[dshn6085])^4))
disp "Beta " _b[dshn6085]/(1+_b[dskn6085]+_b[dshn6085])
disp "Std err. beta " sqrt(((((1+_b[dskn6085])^2)*cov[2,2])+((_b[dshn6085]^2)*cov[1,1])-(2*_b[dshn6085]*(1+_b[dskn6085])*cov[2,1]))/((1+_b[dskn6085]+_b[dshn6085])^4))

*OECD
reg lnyl85 dskn6085 dshn6085 if oecd==1
matrix cov=e(V)
disp "Alpha " _b[dskn6085]/(1+_b[dskn6085]+_b[dshn6085])
disp "Std err. alpha " sqrt(((((1+_b[dshn6085])^2)*cov[1,1])+((_b[dskn6085]^2)*cov[2,2])-(2*_b[dskn6085]*(1+_b[dshn6085])*cov[2,1]))/((1+_b[dskn6085]+_b[dshn6085])^4))
disp "Beta " _b[dshn6085]/(1+_b[dskn6085]+_b[dshn6085])
disp "Std err. beta " sqrt(((((1+_b[dskn6085])^2)*cov[2,2])+((_b[dshn6085]^2)*cov[1,1])-(2*_b[dshn6085]*(1+_b[dskn6085])*cov[2,1]))/((1+_b[dskn6085]+_b[dshn6085])^4))


**Extending the sample period**
*1960-1995*

*Textbook Solow Model
*Unconstrained 1960-95

*Nonoil
reg lnyl95 lnsk6095 lngd6095 if nonoil==1
test lnsk6095+lngd6095=0
*Inter
reg lnyl95 lnsk6095 lngd6095 if inter==1 
test lnsk6095+lngd6095=0

*OECD
reg lnyl95 lnsk6095 lngd6095 if oecd==1
test lnsk6095+lngd6095=0

*Constrained 1960-95
*  --Standard error of alpha calculated by delta method--

*Nonoil
reg lnyl95 dskn6095 if nonoil==1
matrix cov=e(V)
disp "Alpha " (_b[dskn6095]/(1+_b[dskn6095]))
disp "Std err " (sqrt(cov[1,1])/((1+_b[dskn6095])^2))

*Inter
reg lnyl95 dskn6095 if inter==1
matrix cov=e(V)
disp "Alpha " (_b[dskn6095]/(1+_b[dskn6095]))
disp "Std. err " (sqrt(cov[1,1])/((1+_b[dskn6095])^2))


*OECD
reg lnyl95 dskn6095 if oecd==1
matrix cov=e(V)
disp "Alpha " (_b[dskn6095]/(1+_b[dskn6095]))
disp "Std. err " (sqrt(cov[1,1])/((1+_b[dskn6095])^2))


*Augmented Solow Model
*Unconstrained 1960-95

*Nonoil
reg lnyl95 lnsk6095 lngd6095 lnsh6095 if nonoil==1
test lnsk6095+lngd6095+lnsh6095=0

*Inter
reg lnyl95 lnsk6095 lngd6095 lnsh6095 if inter==1
test lnsk6095+lngd6095+lnsh6095=0

*OECD
reg lnyl95 lnsk6095 lngd6095 lnsh6095 if oecd==1
test lnsk6095+lngd6095+lnsh6095=0

*Constrained 1960-95

*Nonoil
reg lnyl95 dskn6095 dshn6095 if nonoil==1
matrix cov=e(V)
disp "Alpha " _b[dskn6095]/(1+_b[dskn6095]+_b[dshn6095])
disp "Std err. alpha " sqrt(((((1+_b[dshn6095])^2)*cov[1,1])+((_b[dskn6095]^2)*cov[2,2])-(2*_b[dskn6095]*(1+_b[dshn6095])*cov[2,1]))/((1+_b[dskn6095]+_b[dshn6095])^4))
disp "Beta " _b[dshn6095]/(1+_b[dskn6095]+_b[dshn6095])
disp "Std err. beta " sqrt(((((1+_b[dskn6095])^2)*cov[2,2])+((_b[dshn6095]^2)*cov[1,1])-(2*_b[dshn6095]*(1+_b[dskn6095])*cov[2,1]))/((1+_b[dskn6095]+_b[dshn6095])^4))

*Inter
reg lnyl95 dskn6095 dshn6095 if inter==1
matrix cov=e(V)
disp "Alpha " _b[dskn6095]/(1+_b[dskn6095]+_b[dshn6095])
disp "Std err. alpha " sqrt(((((1+_b[dshn6095])^2)*cov[1,1])+((_b[dskn6095]^2)*cov[2,2])-(2*_b[dskn6095]*(1+_b[dshn6095])*cov[2,1]))/((1+_b[dskn6095]+_b[dshn6095])^4))
disp "Beta " _b[dshn6095]/(1+_b[dskn6095]+_b[dshn6095])
disp "Std err. beta " sqrt(((((1+_b[dskn6095])^2)*cov[2,2])+((_b[dshn6095]^2)*cov[1,1])-(2*_b[dshn6095]*(1+_b[dskn6095])*cov[2,1]))/((1+_b[dskn6095]+_b[dshn6095])^4))

*OECD
reg lnyl95 dskn6095 dshn6095 if oecd==1
matrix cov=e(V)
disp "Alpha " _b[dskn6095]/(1+_b[dskn6095]+_b[dshn6095])
disp "Std err. alpha " sqrt(((((1+_b[dshn6095])^2)*cov[1,1])+((_b[dskn6095]^2)*cov[2,2])-(2*_b[dskn6095]*(1+_b[dshn6095])*cov[2,1]))/((1+_b[dskn6095]+_b[dshn6095])^4))
disp "Beta " _b[dshn6095]/(1+_b[dskn6095]+_b[dshn6095])
disp "Std err. beta " sqrt(((((1+_b[dskn6095])^2)*cov[2,2])+((_b[dshn6095]^2)*cov[1,1])-(2*_b[dshn6095]*(1+_b[dskn6095])*cov[2,1]))/((1+_b[dskn6095]+_b[dshn6095])^4))



***************************
***SOLOW SUR REGRESSIONS***
***************************

*1960-85*

*Textbook Solow model
*Unconstrained regressions

*Nonoil
sureg (lnyl85 lnsk6085 lngd6085) (gavg6085 sk6085 glf6085 sh6085) if nonoil==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085=0
test [gavg6085]

*Inter
sureg (lnyl85 lnsk6085 lngd6085) (gavg6085 sk6085 glf6085 sh6085) if inter==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085=0
test [gavg6085]

*OECD
sureg (lnyl85 lnsk6085 lngd6085) (gavg6085 sk6085 glf6085 sh6085) if oecd==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085=0
test [gavg6085]

*Western
sureg (lnyl85 lnsk6085 lngd6085) (gavg6085 sk6085 glf6085 sh6085) if western==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085=0
test [gavg6085]

**Constrained regressions

*Nonoil
sureg (lnyl85 dskn6085) (gavg6085 sk6085 glf6085 sh6085) if nonoil==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " ([lnyl85]dskn6085/(1+[lnyl85]dskn6085))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl85]dskn6085)^2))

*Inter
sureg (lnyl85 dskn6085) (gavg6085 sk6085 glf6085 sh6085) if inter==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " ([lnyl85]dskn6085/(1+[lnyl85]dskn6085))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl85]dskn6085)^2))

*OECD
sureg (lnyl85 dskn6085) (gavg6085 sk6085 glf6085 sh6085) if oecd==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " ([lnyl85]dskn6085/(1+[lnyl85]dskn6085))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl85]dskn6085)^2))

*Western
sureg (lnyl85 dskn6085) (gavg6085 sk6085 glf6085 sh6085) if western==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " ([lnyl85]dskn6085/(1+[lnyl85]dskn6085))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl85]dskn6085)^2))

*Augmented Solow Model 1960-85
*Unconstrained Regressions

*Nonoil
sureg (lnyl85 lnsk6085 lngd6085 lnsh6085) (gavg6085 sk6085 glf6085 sh6085) if nonoil==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085+[lnyl85]lnsh6085=0
test [gavg6085]

*Inter
sureg (lnyl85 lnsk6085 lngd6085 lnsh6085) (gavg6085 sk6085 glf6085 sh6085) if inter==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085+[lnyl85]lnsh6085=0
test [gavg6085]

*OECD
sureg (lnyl85 lnsk6085 lngd6085 lnsh6085) (gavg6085 sk6085 glf6085 sh6085) if oecd==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085+[lnyl85]lnsh6085=0
test [gavg6085]

*Western
sureg (lnyl85 lnsk6085 lngd6085 lnsh6085) (gavg6085 sk6085 glf6085 sh6085) if western==1
test [lnyl85]lnsk6085+[lnyl85]lngd6085+[lnyl85]lnsh6085=0
test [gavg6085]

*Constrained Regressions

*Nonoil
sureg (lnyl85 dskn6085 dshn6085) (gavg6085 sk6085 glf6085 sh6085) if nonoil==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " [lnyl85]dskn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. alpha " sqrt(((((1+[lnyl85]dshn6085)^2)*cov[1,1])+(([lnyl85]dskn6085^2)*cov[2,2])-(2*[lnyl85]dskn6085*(1+[lnyl85]dshn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))
disp "Beta " [lnyl85]dshn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. beta " sqrt(((((1+[lnyl85]dskn6085)^2)*cov[2,2])+(([lnyl85]dshn6085^2)*cov[1,1])-(2*[lnyl85]dshn6085*(1+[lnyl85]dskn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))

*Inter
sureg (lnyl85 dskn6085 dshn6085) (gavg6085 sk6085 glf6085 sh6085) if inter==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " [lnyl85]dskn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. alpha " sqrt(((((1+[lnyl85]dshn6085)^2)*cov[1,1])+(([lnyl85]dskn6085^2)*cov[2,2])-(2*[lnyl85]dskn6085*(1+[lnyl85]dshn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))
disp "Beta " [lnyl85]dshn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. beta " sqrt(((((1+[lnyl85]dskn6085)^2)*cov[2,2])+(([lnyl85]dshn6085^2)*cov[1,1])-(2*[lnyl85]dshn6085*(1+[lnyl85]dskn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))

*OECD
sureg (lnyl85 dskn6085 dshn6085) (gavg6085 sk6085 glf6085 sh6085) if oecd==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " [lnyl85]dskn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. alpha " sqrt(((((1+[lnyl85]dshn6085)^2)*cov[1,1])+(([lnyl85]dskn6085^2)*cov[2,2])-(2*[lnyl85]dskn6085*(1+[lnyl85]dshn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))
disp "Beta " [lnyl85]dshn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. beta " sqrt(((((1+[lnyl85]dskn6085)^2)*cov[2,2])+(([lnyl85]dshn6085^2)*cov[1,1])-(2*[lnyl85]dshn6085*(1+[lnyl85]dskn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))

*Western
sureg (lnyl85 dskn6085 dshn6085) (gavg6085 sk6085 glf6085 sh6085) if western==1
test [gavg6085]
matrix cov=e(V)
disp "Alpha " [lnyl85]dskn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. alpha " sqrt(((((1+[lnyl85]dshn6085)^2)*cov[1,1])+(([lnyl85]dskn6085^2)*cov[2,2])-(2*[lnyl85]dskn6085*(1+[lnyl85]dshn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))
disp "Beta " [lnyl85]dshn6085/(1+[lnyl85]dskn6085+[lnyl85]dshn6085)
disp "Std err. beta " sqrt(((((1+[lnyl85]dskn6085)^2)*cov[2,2])+(([lnyl85]dshn6085^2)*cov[1,1])-(2*[lnyl85]dshn6085*(1+[lnyl85]dskn6085)*cov[2,1]))/((1+[lnyl85]dskn6085+[lnyl85]dshn6085)^4))




***SOLOW-SUR 1960-1995***


*1960-95
*Textbook Solow model
*Unconstrained regressions

*Nonoil
sureg (lnyl95 lnsk6095 lngd6095) (gavg6095 sk6095 glf6095 sh6095) if nonoil==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095=0
test [gavg6095]

*Inter
sureg (lnyl95 lnsk6095 lngd6095) (gavg6095 sk6095 glf6095 sh6095) if inter==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095=0
test [gavg6095]

*OECD
sureg (lnyl95 lnsk6095 lngd6095) (gavg6095 sk6095 glf6095 sh6095) if oecd==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095=0
test [gavg6095]

*Western
sureg (lnyl95 lnsk6095 lngd6095) (gavg6095 sk6095 glf6095 sh6095) if western==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095=0
test [gavg6095]

**Constrained regressions

*Nonoil
sureg (lnyl95 dskn6095) (gavg6095 sk6095 glf6095 sh6095) if nonoil==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " ([lnyl95]dskn6095/(1+[lnyl95]dskn6095))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl95]dskn6095)^2))

*Inter
sureg (lnyl95 dskn6095) (gavg6095 sk6095 glf6095 sh6095) if inter==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " ([lnyl95]dskn6095/(1+[lnyl95]dskn6095))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl95]dskn6095)^2))

*OECD
sureg (lnyl95 dskn6095) (gavg6095 sk6095 glf6095 sh6095) if oecd==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " ([lnyl95]dskn6095/(1+[lnyl95]dskn6095))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl95]dskn6095)^2))

*Western
sureg (lnyl95 dskn6095) (gavg6095 sk6095 glf6095 sh6095) if western==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " ([lnyl95]dskn6095/(1+[lnyl95]dskn6095))
disp "Std. err " (sqrt(cov[1,1])/((1+[lnyl95]dskn6095)^2))

*Augmented Solow Model 1960-95
*Unconstrained Regressions

*Nonoil
sureg (lnyl95 lnsk6095 lngd6095 lnsh6095) (gavg6095 sk6095 glf6095 sh6095) if nonoil==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095+[lnyl95]lnsh6095=0
test [gavg6095]

*Inter
sureg (lnyl95 lnsk6095 lngd6095 lnsh6095) (gavg6095 sk6095 glf6095 sh6095) if inter==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095+[lnyl95]lnsh6095=0
test [gavg6095]

*OECD
sureg (lnyl95 lnsk6095 lngd6095 lnsh6095) (gavg6095 sk6095 glf6095 sh6095) if oecd==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095+[lnyl95]lnsh6095=0
test [gavg6095]

*Western
sureg (lnyl95 lnsk6095 lngd6095 lnsh6095) (gavg6095 sk6095 glf6095 sh6095) if western==1
test [lnyl95]lnsk6095+[lnyl95]lngd6095+[lnyl95]lnsh6095=0
test [gavg6095]

*Constrained Regressions

*Nonoil
sureg (lnyl95 dskn6095 dshn6095) (gavg6095 sk6095 glf6095 sh6095) if nonoil==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " [lnyl95]dskn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. alpha " sqrt(((((1+[lnyl95]dshn6095)^2)*cov[1,1])+(([lnyl95]dskn6095^2)*cov[2,2])-(2*[lnyl95]dskn6095*(1+[lnyl95]dshn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))
disp "Beta " [lnyl95]dshn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. beta " sqrt(((((1+[lnyl95]dskn6095)^2)*cov[2,2])+(([lnyl95]dshn6095^2)*cov[1,1])-(2*[lnyl95]dshn6095*(1+[lnyl95]dskn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))

*Inter
sureg (lnyl95 dskn6095 dshn6095) (gavg6095 sk6095 glf6095 sh6095) if inter==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " [lnyl95]dskn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. alpha " sqrt(((((1+[lnyl95]dshn6095)^2)*cov[1,1])+(([lnyl95]dskn6095^2)*cov[2,2])-(2*[lnyl95]dskn6095*(1+[lnyl95]dshn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))
disp "Beta " [lnyl95]dshn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. beta " sqrt(((((1+[lnyl95]dskn6095)^2)*cov[2,2])+(([lnyl95]dshn6095^2)*cov[1,1])-(2*[lnyl95]dshn6095*(1+[lnyl95]dskn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))

*OECD
sureg (lnyl95 dskn6095 dshn6095) (gavg6095 sk6095 glf6095 sh6095) if oecd==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " [lnyl95]dskn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. alpha " sqrt(((((1+[lnyl95]dshn6095)^2)*cov[1,1])+(([lnyl95]dskn6095^2)*cov[2,2])-(2*[lnyl95]dskn6095*(1+[lnyl95]dshn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))
disp "Beta " [lnyl95]dshn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. beta " sqrt(((((1+[lnyl95]dskn6095)^2)*cov[2,2])+(([lnyl95]dshn6095^2)*cov[1,1])-(2*[lnyl95]dshn6095*(1+[lnyl95]dskn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))

*Western
sureg (lnyl95 dskn6095 dshn6095) (gavg6095 sk6095 glf6095 sh6095) if western==1
test [gavg6095]
matrix cov=e(V)
disp "Alpha " [lnyl95]dskn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. alpha " sqrt(((((1+[lnyl95]dshn6095)^2)*cov[1,1])+(([lnyl95]dskn6095^2)*cov[2,2])-(2*[lnyl95]dskn6095*(1+[lnyl95]dshn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))
disp "Beta " [lnyl95]dshn6095/(1+[lnyl95]dskn6095+[lnyl95]dshn6095)
disp "Std err. beta " sqrt(((((1+[lnyl95]dskn6095)^2)*cov[2,2])+(([lnyl95]dshn6095^2)*cov[1,1])-(2*[lnyl95]dshn6095*(1+[lnyl95]dskn6095)*cov[2,1]))/((1+[lnyl95]dskn6095+[lnyl95]dshn6095)^4))




**********************
**AK SUR REGRESSIONS**
**********************

*1960-95*

gen kl95=nrkstk95/(pop95*padult95)
replace kl95=nrkstk94/(pop94*padult94) if country=="TURKEY"
replace kl95=nrkstk94/(pop94*padult94) if country=="SINGAPORE"


gen lnyk95=ln(yl95)-ln(kl95)
gen gnd6095=gavg6095+(glf6095+0.03)

label var lnyk95 "Output/capital, RHS for AK, ln(totaly95)-ln(nrkstk95)"
label var gnd6095 "RHS for AK (2), gavg6095+(glf6095+0.03)"

*NONOIL*
sureg (lnyk95) (gnd6095 sk6095, noconst) if nonoil==1
testnl ln([gnd6095]sk6095)=[lnyk95]_cons

gen gakhat=sk6095*[gnd6095]sk6095-(glf6095+0.03) if e(sample)
disp "Correlation of g, ghat " 
corr gavg6095 gakhat if e(sample)
drop gakhat

*INTER*
sureg (lnyk95) (gnd6095 sk6095, noconst) if inter==1
testnl ln([gnd6095]sk6095)=[lnyk95]_cons

gen gakhat=sk6095*[gnd6095]sk6095-(glf6095+0.03) if e(sample)
disp "Correlation of g, ghat " 
corr gavg6095 gakhat  if e(sample)
drop gakhat

*OECD*
sureg (lnyk95) (gnd6095 sk6095, noconst) if oecd==1
testnl ln([gnd6095]sk6095)=[lnyk95]_cons

gen gakhat=sk6095*[gnd6095]sk6095-(glf6095+0.03) if e(sample)
disp "Correlation of g, ghat " 
corr gavg6095 gakhat if e(sample)
drop gakhat

*WESTERN*
sureg (lnyk95) (gnd6095 sk6095, noconst) if western==1
testnl ln([gnd6095]sk6095)=[lnyk95]_cons

gen gakhat=sk6095*[gnd6095]sk6095-(glf6095+0.03) if e(sample)
disp "Correlation of g, ghat " 
corr gavg6095 gakhat if e(sample)
drop gakhat


***************************
*****GROWTH ACCOUNTING*****
***************************


****Generate TFP GROWTH RATES****

**Assuming 7% return to education**

*Actual labor shares*
gen gt7a6595=gy6595-(1-labshare)*gk6595-labshare*(glf6595+gh76595)
gen gt7a6580=gy6580-(1-labshare)*gk6580-labshare*(glf6580+gh76580)
gen gt7a8095=gy8095-(1-labshare)*gk8095-labshare*(glf8095+gh78095)

label var gt7a6595 "Average growth rate of TFP 1965-95, actual labor shares, 7% return to education"

*Labor's share=0.65*
gen gt7c6595=gy6595-0.35*gk6595-0.65*(glf6595+gh76595)
gen gt7c6580=gy6580-0.35*gk6580-0.65*(glf6580+gh76580)
gen gt7c8095=gy8095-0.35*gk8095-0.65*(glf8095+gh78095)

label var gt7c6595 "Average growth rate of TFP 1965-95, labor shares=0.65, 7% return to education"

**Assuming no returns to education**

*Actual labor shares*
gen gt0a6595=gy6595-(1-labshare)*gk6595-labshare*glf6595
gen gt0a6580=gy6580-(1-labshare)*gk6580-labshare*glf6580
gen gt0a8095=gy8095-(1-labshare)*gk8095-labshare*glf8095

label var gt0a6595 "Average growth rate of TFP 1965-95, actual labor shares, no returns to education"

*Labor's share=0.65*
gen gt0c6595=gy6595-0.35*gk6595-0.65*glf6595
gen gt0c6580=gy6580-0.35*gk6580-0.65*glf6580
gen gt0c8095=gy8095-0.35*gk8095-0.65*glf8095

label var gt0c6595 "Average growth rate of TFP 1965-95, labor share=0.65, no returns to education"




*************************************
*****TFP GROWTH RATE REGRESSIONS*****
*************************************

**1965-95**
reg gt7a6595 sk6595
reg gt7a6595 sh6595
reg gt7a6595 glf6595
reg gt7a6595 sk6595 sh6595
reg gt7a6595 sk6595 glf6595
reg gt7a6595 sh6595 glf6595
reg gt7a6595 sk6595 sh6595 glf6595

reg gt7c6595 sk6595
reg gt7c6595 sh6595
reg gt7c6595 glf6595
reg gt7c6595 sk6595 sh6595
reg gt7c6595 sk6595 glf6595
reg gt7c6595 sh6595 glf6595
reg gt7c6595 sk6595 sh6595 glf6595

reg gt0a6595 sk6595
reg gt0a6595 sh6595
reg gt0a6595 glf6595
reg gt0a6595 sk6595 sh6595
reg gt0a6595 sk6595 glf6595
reg gt0a6595 sh6595 glf6595
reg gt0a6595 sk6595 sh6595 glf6595

reg gt0c6595 sk6595
reg gt0c6595 sh6595
reg gt0c6595 glf6595
reg gt0c6595 sk6595 sh6595
reg gt0c6595 sk6595 glf6595
reg gt0c6595 sh6595 glf6595
reg gt0c6595 sk6595 sh6595 glf6595

**1965-80**
reg gt7a6580 sk6580
reg gt7a6580 sh6580
reg gt7a6580 glf6580
reg gt7a6580 sk6580 sh6580
reg gt7a6580 sk6580 glf6580
reg gt7a6580 sh6580 glf6580
reg gt7a6580 sk6580 sh6580 glf6580

reg gt7c6580 sk6580
reg gt7c6580 sh6580
reg gt7c6580 glf6580
reg gt7c6580 sk6580 sh6580
reg gt7c6580 sk6580 glf6580
reg gt7c6580 sh6580 glf6580
reg gt7c6580 sk6580 sh6580 glf6580

reg gt0a6580 sk6580
reg gt0a6580 sh6580
reg gt0a6580 glf6580
reg gt0a6580 sk6580 sh6580
reg gt0a6580 sk6580 glf6580
reg gt0a6580 sh6580 glf6580
reg gt0a6580 sk6580 sh6580 glf6580

reg gt0c6580 sk6580
reg gt0c6580 sh6580
reg gt0c6580 glf6580
reg gt0c6580 sk6580 sh6580
reg gt0c6580 sk6580 glf6580
reg gt0c6580 sh6580 glf6580
reg gt0c6580 sk6580 sh6580 glf6580

**1980-95**
reg gt7a8095 sk8095
reg gt7a8095 sh8095
reg gt7a8095 glf8095
reg gt7a8095 sk8095 sh8095
reg gt7a8095 sk8095 glf8095
reg gt7a8095 sh8095 glf8095
reg gt7a8095 sk8095 sh8095 glf8095

reg gt7c8095 sk8095
reg gt7c8095 sh8095
reg gt7c8095 glf8095
reg gt7c8095 sk8095 sh8095
reg gt7c8095 sk8095 glf8095
reg gt7c8095 sh8095 glf8095
reg gt7c8095 sk8095 sh8095 glf8095

reg gt0a8095 sk8095
reg gt0a8095 sh8095
reg gt0a8095 glf8095
reg gt0a8095 sk8095 sh8095
reg gt0a8095 sk8095 glf8095
reg gt0a8095 sh8095 glf8095
reg gt0a8095 sk8095 sh8095 glf8095

reg gt0c8095 sk8095
reg gt0c8095 sh8095
reg gt0c8095 glf8095
reg gt0c8095 sk8095 sh8095
reg gt0c8095 sk8095 glf8095
reg gt0c8095 sh8095 glf8095
reg gt0c8095 sk8095 sh8095 glf8095

***************************************************************************************
***** GENERATE FIGURES                                                            *****
***************************************************************************************

***0% return to education***

***Figure 1***
reg gt0a6595 sk6595 if gsample==1
predict hat if e(sample)

graph7 gt0a6595 hat sk6595 if gsample==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 1: Relation of TFP growth to saving rate") ///
b2(Saving rate, 1965-95) gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Actual labor shares, no return to education)") ///
psize(120)

graph export bgfigure1.wmf,replace
	
graph twoway scatter gt0a6595 sk6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt0a6595 sk6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0,lpattern(dash)lwidth(thin)lcolor(gs0)) ///
title("Figure 1: Relation of TFP growth to saving rate",size(4)) ///
subtitle("(Fitted values, actual labor shares, no return to education)",size(3)) ///
xtitle("Saving rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white))

graph export bgfigure1.ps,replace

drop hat

***Figure 2***
reg gt0a6595 sh6595 if gsample==1
predict hat if e(sample)

graph7 gt0a6595 hat sh6595 if gsample==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 2: Relation of TFP growth to schooling rate") ///
b2(Human capital investment rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Actual labor shares, no returns to education)") ///
psize(120)

graph export bgfigure2.wmf,replace

graph twoway scatter gt0a6595 sh6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt0a6595 sh6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0,lpattern(dash)lwidth(thin)lcolor(gs0)) ///
title("Figure 2: Relation of TFP growth to schooling rate",size(4)) ///
subtitle("(Fitted values, actual labor shares, no return to education)",size(3)) ///
xtitle("Human capital investment rate, 1965-95, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure2.ps,replace

drop hat

***Figure 3***
reg gt0a6595 glf6595 if gsample==1
predict hat if e(sample)

graph7 gt0a6595 hat glf6595 if gsample==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 3: Relation of TFP growth to labor force growth rate") ///
b2(Labor force growth rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Actual labor shares, no returns to education)") ///
psize(120)

graph export bgfigure3.wmf,replace

graph twoway scatter gt0a6595 glf6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt0a6595 glf6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 3: Relation of TFP growth to labor force growth rate",size(4)) ///
subtitle("(Fitted values, actual labor shares, no return to education)",size(3)) ///
xtitle("Labor force growth rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure3.ps,replace

drop hat

***Figure 4***
reg gt0c6595 sk6595 if nonoil==1
predict hat if e(sample)

graph7 gt0c6595 hat sk6595 if nonoil==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 4: Relation of TFP growth to saving rate") ///
b2(Saving rate, 1965-95) gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Labor share=0.65, no returns to education)") ///
psize(120)

graph export bgfigure4.wmf,replace

graph twoway scatter gt0c6595 sk6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt0c6595 sk6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 4: Relation of TFP growth to saving rate",size(4)) ///
subtitle("(Fitted values, labor share=0.65, no return to education)",size(3)) ///
xtitle("Saving rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure4.ps,replace

drop hat 

***Figure 5***
reg gt0c6595 sh6595 if nonoil==1
predict hat if e(sample)

graph7 gt0c6595 hat sh6595 if nonoil==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 5: Relation of TFP growth to schooling rate") ///
b2(Human capital investment rate, 1965-95) gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Labor share=0.65, no returns to education)") ///
psize(120)

graph export bgfigure5.wmf,replace

graph twoway scatter gt0c6595 sh6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt0c6595 sh6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 5: Relation of TFP growth to schooling rate",size(4)) ///
subtitle("(Fitted values, labor share=0.65, no return to education)",size(3)) ///
xtitle("Human capital investment rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure5.ps,replace

drop hat

***Figure 6***
reg gt0c6595 glf6595 if nonoil==1
predict hat if e(sample)

graph7 gt0c6595 hat glf6595 if nonoil==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 6: Relation of TFP growth to labor force growth rate") ///
b2(Labor force growth rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Labor share=0.65, no returns to education)") ///
psize(120)

graph export bgfigure6.wmf,replace

graph twoway scatter gt0c6595 glf6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt0c6595 glf6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 6: Relation of TFP growth to labor force growth rate",size(4)) ///
subtitle("(Fitted values, labor share=0.65, no return to education)",size(3)) ///
xtitle("Labor force growth rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure6.ps,replace


***7% Return to education***

drop hat

***Figure 7***
reg gt7a6595 sk6595 if gsample==1
predict hat if e(sample)

graph7 gt7a6595 hat sk6595 if gsample==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 7: Relation of TFP growth to saving rate") ///
b2(Saving rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Actual labor shares, 7% return to education)") ///
psize(120)

graph export bgfigure7.wmf,replace

graph twoway scatter gt7a6595 sk6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt7a6595 sk6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 7: Relation of TFP growth to saving rate",size(4)) ///
subtitle("(Fitted values, actual labor shares, 7% return to education)",size(3)) ///
xtitle("Saving rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure7.ps,replace

drop hat

***Figure 8***
reg gt7a6595 sh6595 if gsample==1
predict hat if e(sample)

graph7 gt7a6595 hat sh6595 if gsample==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 8: Relation of TFP growth to schooling rate") ///
b2(Human capital investment rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Actual labor shares, 7% return to education)") ///
psize(120)

graph export bgfigure8.wmf,replace

graph twoway scatter gt7a6595 sh6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt7a6595 sh6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 8: Relation of TFP growth to schooling rate",size(4)) ///
subtitle("(Fitted values, actual labor shares, 7% return to education)",size(3)) ///
xtitle("Human capital investment rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure8.ps,replace

drop hat

***Figure 9***
reg gt7a6595 glf6595 if gsample==1
predict hat if e(sample)

graph7 gt7a6595 hat glf6595 if gsample==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 9: Relation of TFP growth to labor force growth rate") ///
b2(Labor force growth rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Actual labor shares, 7% return to education)") ///
psize(120)

graph export bgfigure9.wmf,replace

graph twoway scatter gt7a6595 glf6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt7a6595 glf6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 9: Relation of TFP growth to labor force growth rate",size(4)) ///
subtitle("(Fitted values, actual labor shares, 7% return to education)",size(3)) ///
xtitle("Labor force growth rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure9.ps,replace

drop hat

***Figure 10***
reg gt7c6595 sk6595 if nonoil==1
predict hat if e(sample)

graph7 gt7c6595 hat sk6595 if nonoil==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 10: Relation of TFP growth to saving rate") ///
b2(Saving rate, 1965-95) gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Labor share=0.65, 7% return to education)") ///
psize(120)

graph export bgfigure10.wmf,replace

graph twoway scatter gt7c6595 sk6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt7c6595 sk6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 10: Relation of TFP growth to saving rate",size(4)) ///
subtitle("(Fitted values, labor share=0.65, 7% return to education)",size(3)) ///
xtitle("Saving rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure10.ps,replace

drop hat

***Figure 11***
reg gt7c6595 sh6595 if nonoil==1
predict hat if e(sample)

graph7 gt7c6595 hat sh6595 if nonoil==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 11: Relation of TFP growth to schooling rate") ///
b2(Human capital investment rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Labor share=0.65, 7% return to education)") ///
psize(120)

graph export bgfigure11.wmf,replace

graph twoway scatter gt7c6595 sh6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt7c6595 sh6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 11: Relation of TFP growth to schooling rate",size(4)) ///
subtitle("(Fitted values, labor share=0.65, 7% return to education)",size(3)) ///
xtitle("Human capital investment rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure11.ps,replace

drop hat

***Figure 12***
reg gt7c6595 glf6595 if nonoil==1
predict hat if e(sample)

graph7 gt7c6595 hat glf6595 if nonoil==1, c(.l) s([wbcode]i) sort ylabel xlabel border yline(0) ///
b1("Figure 12: Relation of TFP growth to labor force growth rate") ///
b2(Labor force growth rate, 1965-95)gap(5) ///
l1(TFP growth rate, 1965-95) ///
l2("(Labor share=0.65, 7% return to education)") ///
psize(120)

graph export bgfigure12.wmf,replace

graph twoway scatter gt7c6595 glf6595 if gsample==1, jitter(2) msymbol(O) msize(vsmall) mcolor(gs0) mlabel(wbcode) mlabpos(3) mlabsize(vsmall) mlabcolor(gs0) ///
|| lfit gt7c6595 glf6595 if gsample==1, sort lpattern(solid) lwidth(thin) lcolor(gs0) yline(0, lpattern(dash) lwidth(thin) lcolor(gs0)) ///
title("Figure 12: Relation of TFP growth to labor force growth rate",size(4)) ///
subtitle("(Fitted values, labor share=0.65, 7% return to education)",size(3)) ///
xtitle("Labor force growth rate, 1965-95",size(4)) xsca(titlegap(4)) ysca(titlegap(8)) ///
ytitle("TFP growth rate, 1965-95",size(4)) ///
legend(off) graphregion(fcolor(white)) 

graph export bgfigure12.ps,replace

drop hat


*********************** 
***GENERATE APPENDIX***
*********************** 

**TFP GROWTH RATES**

*ACTUAL LABOR SHARES*

list country gt0a6595 gt0a6580 gt0a8095 if nonoil==1
list country gt7a6595 gt7a6580 gt7a8095 if nonoil==1

*LABOR SHARE=0.65*

list country gt0c6595 gt0c6580 gt0c8095 if nonoil==1
list country gt7c6595 gt7c6580 gt7c8095 if nonoil==1

**GROWTH RATE OF INPUTS AND OUTPUT**

list country gy6595 gk6595 gh76595 glf6595 if nonoil==1

*****************************************
***GENERATE DATA FILE FOR RATS PROGRAM***
*****************************************

format totaly60 totaly95 nrkstk60 nrkstk95 %14.2f
mvencode _all, mv(-999)
outsheet  nonoil inter oecd western yl60 yl95 gavg6095 sk6095 sh6095 glf6095 using c:\growth\bg2001nl.csv if nonoil==1 , comma  replace
mvdecode _all, mv(-999)


set more on
log close


